@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# $XFree86: test/xsuite/run.sh,v 1.5 2004/01/26 15:25:53 dawes Exp $
+# $XFree86: test/xsuite/run.sh,v 1.7 2004/02/04 02:05:31 dawes Exp $
 #
 # A script for running the xtest suite.
 #
@@ -114,9 +114,9 @@ if [ "$newsettings" = y ]; then
 	XT_WIDTH_MM="$param"
 	GetParam "Enter the screen height in millimeters:" "$XT_HEIGHT_MM"
 	XT_HEIGHT_MM="$param"
-	GetParam "Enter the list of pixmap depths:" "$XT_PIXMAP_DEPTHS"
+	GetParam "Enter the list of pixmap depths (space separated):" "$XT_PIXMAP_DEPTHS"
 	XT_PIXMAP_DEPTHS="$param"
-	XT_PIXMAP_DEPTHS="`echo $XT_PIXMAP_DEPTHS | sed s/,//g`"
+	XT_PIXMAP_DEPTHS="`echo $XT_PIXMAP_DEPTHS | sed 's/,/ /g'`"
 	GetParam "Enter the depth of the root window:" "$XT_ROOT_DEPTH"
 	oldDepth="$XT_ROOT_DEPTH"
 	XT_ROOT_DEPTH="$param"
